@@ -1,5 +1,5 @@
 from .node import Node, NodeException
-from .resolver import Resolver, ResolverException, UpdateOperation
+from .resolver import Resolver, ResolverException, UpdateOperation, FilterConnector
 from .batch import Batch
 from .unset import Unset, ComputedPropertyException, AppendixPropertyException, is_unset
 from .validators import from_str, enum_from_str
